# systemd options
%global _has_systemd %(eval rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  %global _servicefile_postfix %{_has_systemd}.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

Summary: Software RAID monitoring tool
Name: raidmon
Version: 2.4.3
Release: 4%{?dist}
Group: System Environment/Daemons
License: GPLv2+
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: %{name}.%{_servicefile_postfix}
Source1: %{name}.sysconfig
Source2: %{name}.sh.in
Source3: %{name}.cron
%if %{_has_systemd}
Source4: %{name}-tmpfiles.conf
%endif
Source5: README.%{name}
Source6: CREDITS.%{name}
Source7: http://www.gnu.org/licenses/gpl.txt
Requires: sendEmail >= 1.50, beep, grep, util-linux, procps, rsync
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
BuildRequires: sed
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
Raidmon is a shell script which runs as a daemon and monitors software
RAID devices (Linux MD). It starts to beep when a disk fails or while
a RAID device is resyncing after an unclean shutdown. Every event also
triggers the email alert mechanism, which sends mail to one or more
persons with the details of what's going on.

%prep
%{__install} -d %{_builddir}/%{name}-%{version}
%{__install} -m 0644 -p %{SOURCE5} %{_builddir}/%{name}-%{version}/README
%{__install} -m 0644 -p %{SOURCE6} %{_builddir}/%{name}-%{version}/CREDITS
%{__install} -m 0644 -p %{SOURCE7} %{_builddir}/%{name}-%{version}/LICENSE

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -d %{buildroot}%{_sysconfdir}/cron.daily
%{__install} -d %{buildroot}%{_bindir}
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE4} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE0} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE0} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__sed} -e "s@\/var\/run\/@%{_pidbasedir}/@g" %{SOURCE2} > %{buildroot}%{_bindir}/%{name}
%{__chmod} 0755 %{buildroot}%{_bindir}/%{name}
%{__install} -m 0755 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/cron.daily/0%{name}

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%{_bindir}/systemctl daemon-reload > /dev/null 2>&1 || :
if [ $1 -ge 1 ]; then
  %{_bindir}/%{name} try-restart > /dev/null 2>&1 || :
fi
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc %{name}-%{version}/README %{name}-%{version}/CREDITS %{name}-%{version}/LICENSE
%{_bindir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%else
%attr(0755,root,root) %config %{_initrddir}/%{name}
%endif
%attr(0755,root,root) %dir %{_pidbasedir}/%{name}
%attr(0755,root,root) %config %{_sysconfdir}/cron.daily/0%{name}

%changelog
* Mon Mar 06 2023 Simon Matter <simon.matter@invoca.ch> 2.4.3-4
- add also Wants=network-online.target to systemd unit files

* Fri Mar 03 2023 Simon Matter <simon.matter@invoca.ch> 2.4.3-3
- add network-online requirement to systemd unit files

* Mon Jan 23 2023 Simon Matter <simon.matter@invoca.ch> 2.4.3-1
- upgrade to 2.4.3 (improve mechanism for reexec)

* Fri Jan 20 2023 Simon Matter <simon.matter@invoca.ch> 2.4.2-1
- upgrade to 2.4.2 (improve syslog info)

* Fri Jan 20 2023 Simon Matter <simon.matter@invoca.ch> 2.4.1-1
- upgrade to 2.4.1 (improve reload function)

* Thu Jan 19 2023 Simon Matter <simon.matter@invoca.ch> 2.4.0-1
- upgrade to 2.4.0 (refactoring for new bash style)

* Fri Jan 13 2023 Simon Matter <simon.matter@invoca.ch> 2.3.6-1
- upgrade to 2.3.6 (fix lsblk emulation)

* Thu Jan 12 2023 Simon Matter <simon.matter@invoca.ch> 2.3.5-1
- upgrade to 2.3.5 (cosmetic changes)

* Thu Jan 12 2023 Simon Matter <simon.matter@invoca.ch> 2.3.4-1
- upgrade to 2.3.4 (add disk info to long status)

* Tue Jan 10 2023 Simon Matter <simon.matter@invoca.ch> 2.3.3-1
- upgrade to 2.3.3 (get rid of dangerous eval)

* Tue Jan 10 2023 Simon Matter <simon.matter@invoca.ch> 2.3.2-1
- upgrade to 2.3.2 (sort device list of disk info)

* Tue Jan 10 2023 Simon Matter <simon.matter@invoca.ch> 2.3.1-1
- upgrade to 2.3.1 (add more info to disk info)

* Tue Jan 10 2023 Simon Matter <simon.matter@invoca.ch> 2.3.0-1
- upgrade to 2.3.0 (add disk info to long status)

* Thu Aug 19 2021 Simon Matter <simon.matter@invoca.ch> 2.2.5-3
- improve init script

* Wed Aug 18 2021 Simon Matter <simon.matter@invoca.ch> 2.2.5-2
- fix inconsistency between init scripts and systemd

* Wed Aug 18 2021 Simon Matter <simon.matter@invoca.ch> 2.2.5-1
- upgrade to 2.2.5

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.2.4-1
- upgrade to 2.2.4

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.2.3-1
- upgrade to 2.2.3

* Sat Aug 14 2021 Simon Matter <simon.matter@invoca.ch> 2.2.2-1
- upgrade to 2.2.2

* Fri Aug 13 2021 Simon Matter <simon.matter@invoca.ch> 2.2.1-1
- upgrade to 2.2.1

* Fri Aug 13 2021 Simon Matter <simon.matter@invoca.ch> 2.2.0-1
- upgrade to 2.2.0

* Fri Dec 04 2020 Simon Matter <simon.matter@invoca.ch> 2.1.7-1
- upgrade to 2.1.7

* Mon Apr 20 2020 Simon Matter <simon.matter@invoca.ch> 2.1.6-1
- upgrade to 2.1.6
- add support for EL8

* Thu Apr 25 2019 Simon Matter <simon.matter@invoca.ch> 2.1.5-1
- upgrade to 2.1.5

* Wed Oct 03 2018 Simon Matter <simon.matter@invoca.ch> 2.1.4-1
- upgrade to 2.1.4

* Fri Sep 28 2018 Simon Matter <simon.matter@invoca.ch> 2.1.3-1
- upgrade to 2.1.3

* Tue Sep 11 2018 Simon Matter <simon.matter@invoca.ch> 2.1.2-1
- upgrade to 2.1.2

* Tue Sep 11 2018 Simon Matter <simon.matter@invoca.ch> 2.1.0-1
- upgrade to 2.1.0

* Thu Sep 06 2018 Simon Matter <simon.matter@invoca.ch> 2.0.9-1
- upgrade to 2.0.9

* Fri Aug 31 2018 Simon Matter <simon.matter@invoca.ch> 2.0.8-1
- upgrade to 2.0.8

* Fri Aug 31 2018 Simon Matter <simon.matter@invoca.ch> 2.0.7-1
- upgrade to 2.0.7

* Wed Jun 27 2018 Simon Matter <simon.matter@invoca.ch> 2.0.6-1
- upgrade to 2.0.6

* Mon Jun 25 2018 Simon Matter <simon.matter@invoca.ch> 2.0.5-1
- upgrade to 2.0.5

* Fri May 29 2015 Simon Matter <simon.matter@invoca.ch> 2.0.4-1
- upgrade to 2.0.4

* Thu May 28 2015 Simon Matter <simon.matter@invoca.ch> 2.0.3-1
- upgrade to 2.0.3

* Mon May 18 2015 Simon Matter <simon.matter@invoca.ch> 2.0.2-1
- upgrade to 2.0.2

* Wed May 13 2015 Simon Matter <simon.matter@invoca.ch> 2.0.1-2
- small spec fixes for systemd

* Wed Apr 29 2015 Simon Matter <simon.matter@invoca.ch> 2.0.1-1
- upgrade to 2.0.1

* Tue Apr 28 2015 Simon Matter <simon.matter@invoca.ch> 2.0.0-1
- upgrade to 2.0.0
- add support for systemd

* Tue Nov 19 2013 Simon Matter <simon.matter@invoca.ch> 1.8.4-1
- upgrade to 1.8.4

* Thu Nov 15 2012 Simon Matter <simon.matter@invoca.ch> 1.8.3-2
- increase priority of daily cron job

* Fri Nov 09 2012 Simon Matter <simon.matter@invoca.ch> 1.8.3-1
- upgrade to 1.8.3

* Thu Nov 08 2012 Simon Matter <simon.matter@invoca.ch> 1.8.2-1
- upgrade to 1.8.2

* Fri Aug 05 2011 Simon Matter <simon.matter@invoca.ch> 1.8.1-1
- upgrade to 1.8.1

* Fri Aug 05 2011 Simon Matter <simon.matter@invoca.ch> 1.8.0-1
- upgrade to 1.8.0, reports check and resync as syncing array

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 1.7.5-2
- mass rebuild

* Tue Nov 10 2009 Simon Matter <simon.matter@invoca.ch> 1.7.5-1
- upgrade to 1.7.5, which now reports recovering state but reports
  resyncing state changes only once

* Mon Nov 02 2009 Simon Matter <simon.matter@invoca.ch> 1.7.4-1
- upgrade to 1.7.4, don't treat resyncing state as critical
- change license tag to GPLv2+

* Sat Sep 27 2008 Simon Matter <simon.matter@invoca.ch> 1.7.3-1
- upgrade to 1.7.3, fix issue with restarting, add pid handling

* Fri Sep 26 2008 Simon Matter <simon.matter@invoca.ch> 1.7.1-1
- upgrade to 1.7.1, fix error messages from beep on XEN DomU's

* Fri Sep 26 2008 Simon Matter <simon.matter@invoca.ch> 1.7.0-1
- upgrade to 1.7.0, adds signal handler and proper daemonizing

* Fri Oct 12 2007 Simon Matter <simon.matter@invoca.ch> 1.6.3-1
- bring in sync with ccissmon and mpiomon

* Fri Dec 15 2006 Simon Matter <simon.matter@invoca.ch> 1.6.2-1
- upgrade to 1.6.2, which reexecs itself when not called as raidmon

* Fri Dec 08 2006 Simon Matter <simon.matter@invoca.ch> 1.6.1-1
- upgrade to 1.6.1, which doesn't beep on condrestart and handles
  wrong status parameters with an error message

* Wed Dec 06 2006 Simon Matter <simon.matter@invoca.ch> 1.6.0-1
- upgrade to 1.6.0, which tries to stay in sync with mpiomon

* Thu Nov 30 2006 Simon Matter <simon.matter@invoca.ch> 1.5.2-1
- upgrade to raidmon-1.5.2

* Tue May 09 2006 Simon Matter <simon.matter@invoca.ch> 1.5.1-1
- upgrade to raidmon-1.5.1

* Thu Mar 23 2006 Simon Matter <simon.matter@invoca.ch> 1.5.0-1
- upgrade to raidmon-1.5.0

* Thu Dec 08 2005 Simon Matter <simon.matter@invoca.ch> 1.4.6-1
- upgrade to raidmon-1.4.6

* Mon Jul 18 2005 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.4.5, makes beep work on kernel >= 2.5

* Tue Jan 18 2005 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.4.4, fixes a serious bug in loop
  handling when alarms have been confirmed

* Fri Oct 08 2004 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.4.3

* Thu Oct 07 2004 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.4.2

* Wed Oct 06 2004 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.4.1

* Fri Aug 13 2004 Simon Matter <simon.matter@invoca.ch>
- created absolute symlink
- added additional status parameters [number|syncing|failed]

* Fri Jun 11 2004 Simon Matter <simon.matter@invoca.ch>
- added beephours patch provided by Thomas Jarosch, thank you!

* Sat Jan 10 2004 Simon Matter <simon.matter@invoca.ch>
- added symlink to /usr/bin

* Mon Nov 17 2003 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.3.1

* Thu Nov 13 2003 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.3.0
- added new dependency for sendEmail

* Sat Apr 26 2003 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.2.1

* Sat Apr 26 2003 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.2.0

* Tue Apr 08 2003 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.1.6
- added proper licenses

* Sat Feb 08 2003 Simon Matter <simon.matter@invoca.ch>
- upgrade to raidmon-1.1.5

* Tue Jun 11 2002 Simon Matter <simix@datacomm.ch>
- added cron.daily job

* Mon May 03 2002 Simon Matter <simix@datacomm.ch>
- upgrade to raidmon-1.1.4

* Thu Mar 28 2002 Simon Matter <simix@datacomm.ch>
- upgrade to raidmon-1.1.3

* Sat Mar 16 2002 Simon Matter <simix@datacomm.ch>
- initial build
